@@ -1,3 +1,4 @@
+"""Base service for all RESTful endpoints."""
 from flask import request, jsonify, make_response
 from flask.views import MethodView
 
@@ -13,14 +14,14 @@ class Service(MethodView):
     def get(self, resource_id):
         """Return response to HTTP GET request."""
         if resource_id is None:
-            return self.all_resources()
+            return self._all_resources()
         else:
-            resource = self.resource(resource_id)
+            resource = self._resource(resource_id)
             if not resource:
                 raise NotFoundException
             return jsonify(resource.to_dict())
 
-    def all_resources(self):
+    def _all_resources(self):
         """Return all resources of this type as a JSON list."""
         if not 'page' in request.args:
             resources = self.__db__.session.query(self.__model__).all()
@@ -31,18 +32,19 @@ class Service(MethodView):
     @verify_fields
     def post(self, resource_id=None):
         """Return response to HTTP POST request."""
+        # pylint: disable=unused-argument
         resource = self.__model__.query.filter_by(**request.json).first()
         # resource already exists; don't create it again
         if resource:
             return self._no_content_response()
-        instance = self.__model__(**request.json)
+        instance = self.__model__(**request.json) #pylint: disable=not-callable
         self.__db__.session.add(instance)
         self.__db__.session.commit()
         return self._created_response(instance.to_dict())
 
     def delete(self, resource_id):
         """Return response to HTTP DELETE request."""
-        instance = self.resource(resource_id)
+        instance = self._resource(resource_id)
         self.__db__.session.delete(instance)
         self.__db__.session.commit()
         return self._no_content_response()
@@ -50,9 +52,9 @@ class Service(MethodView):
     @verify_fields
     def put(self, resource_id):
         """Return response to HTTP PUT request."""
-        instance = self.resource(resource_id)
+        instance = self._resource(resource_id)
         if instance is None:
-            instance = self.__model__(**request.json)
+            instance = self.__model__(**request.json) #pylint: disable=not-callable
         else:
             instance.from_dict(request.json)
         self.__db__.session.add(instance)
@@ -62,13 +64,13 @@ class Service(MethodView):
     @verify_fields
     def patch(self, resource_id):
         """Return response to HTTP PATCH request."""
-        resource = self.resource(resource_id)
+        resource = self._resource(resource_id)
         resource.from_dict(request.json)
         self.__db__.session.add(resource)
         self.__db__.session.commit()
         return self._created_response(resource.to_dict())
 
-    def resource(self, resource_id):
+    def _resource(self, resource_id):
         """Return resource represented by this *resource_id*."""
         resource = self.__db__.session.query(self.__model__).get(resource_id)
         if not resource:
